.. stubalyzer documentation master file, created by
   sphinx-quickstart on Wed Oct 23 17:26:51 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Stubalyzer Documentation
========================

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   README
   api/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
